extends Node2D

@onready var tex = $TextureRect
@onready var dialog = $FileDialog

func _on_file_dialog_file_selected(path: String) -> void:
	# ----------------------------
	# 参考スレッド
	# https://www.reddit.com/r/godot/comments/ox381i/how_can_i_load_a_image_from_my_filesystem_into_my/
	# ----------------------------
	print("path:", path)
	
	# FileAccess で読み込む.
	# load() は "res://" "user://" 以外では使えない.
	var file = FileAccess.open(path, FileAccess.READ)
	
	var bytes = file.get_buffer(file.get_length())
	var img = Image.new()
	
	# 拡張子によって読み込み方法が異なる.
	if path.ends_with(".png") || path.ends_with(".PNG"):
		# warning-ignore:unused_variable
		var error = img.load_png_from_buffer(bytes)
		assert(error == Error.OK, "can't open file: %s"%path)
		
	elif path.ends_with(".jpg") || path.ends_with(".jpeg") || path.ends_with(".JPG") || path.ends_with(".JPEG"):
		# warning-ignore:unused_variable
		var error = img.load_jpg_from_buffer(bytes)
		assert(error == Error.OK, "can't open file: %s"%path)
		
	else:
		assert(false, "can't open file: %s"%path)

	# ImageTexture経由でテクスチャにする.
	var imgtex = ImageTexture.new()
	# Godot4.x では create_from_image() から set_image() に変わった.
	#imgtex.create_from_image(img)
	imgtex.set_image(img)
	print("format:", imgtex.get_format())
	print("width:", imgtex.get_width())
	print("height:", imgtex.get_height())
	
	# ファイル閉じる.
	file.close()
	
	# テクスチャを設定する.
	tex.texture = imgtex


## 画像を読み込むボタンを押した
func _on_button_pressed() -> void:
	# ダイアログを表示
	dialog.show()
